==> tivio_sdk-1.0.0.tar.gz: lib/logger.dart <==
import 'package:logger/logger.dart' as DartLogger;
import 'package:tivio_sdk/tivio.dart';
import 'dart:convert';
import 'enums/tivio_log_levels.dart';

class Logger {
  static final Logger _instance = Logger._internal();
  DartLogger.Logger _logger;
  //final _jsonEncoder = JsonEncoder();

  factory Logger() {
    return _instance;
  }

  Logger._internal();

  static DartLogger.Level tivioLogLevelsToDartLoggerLevels (TivioLogLevels tivioLogLevel) {
    switch (tivioLogLevel) {
      case TivioLogLevels.nothing: return DartLogger.Level.nothing;
      case TivioLogLevels.info: return DartLogger.Level.info;
      case TivioLogLevels.debug: return DartLogger.Level.debug;
      case TivioLogLevels.error: return DartLogger.Level.error;
      case TivioLogLevels.verbose: return DartLogger.Level.verbose;
      case TivioLogLevels.warning: return DartLogger.Level.warning;
    }

    return DartLogger.Level.nothing;
  }

  init(TivioLogLevels logLevel) {
    if (_instance._logger == null) {
      print('Initializing tivio logger with level: $logLevel');
      _instance._logger = DartLogger.Logger(level: Logger.tivioLogLevelsToDartLoggerLevels(logLevel));
    }
  }

  info(dynamic message) {
    _getLogger().i(message);
  }

  debug(dynamic message) {
    _getLogger().d(message);
  }

  verbose(dynamic message) {
    _getLogger().v(message);
  }

  warning(dynamic message) {
    _getLogger().w(message);
  }

  error(dynamic message) {
    _getLogger().e(message);
  }

  DartLogger.Logger _getLogger() {
    if (_logger == null) {
      throw new Exception('Logger is not initialized.');
    }

    return _logger;
  }
}

==> tivio_sdk-1.2.0.tar.gz: lib/logger.dart <==
import 'package:logger/logger.dart' as DartLogger;
import 'package:tivio_sdk/tivio.dart';
import 'enums/tivio_log_levels.dart';

class Logger {
  static final Logger _instance = Logger._internal();
  DartLogger.Logger? _logger;

  factory Logger() {
    return _instance;
  }

  Logger._internal();

  static DartLogger.Level tivioLogLevelsToDartLoggerLevels (TivioLogLevels tivioLogLevel) {
    switch (tivioLogLevel) {
      case TivioLogLevels.nothing: return DartLogger.Level.nothing;
      case TivioLogLevels.info: return DartLogger.Level.info;
      case TivioLogLevels.debug: return DartLogger.Level.debug;
      case TivioLogLevels.error: return DartLogger.Level.error;
      case TivioLogLevels.verbose: return DartLogger.Level.verbose;
      case TivioLogLevels.warning: return DartLogger.Level.warning;
    }

    return DartLogger.Level.nothing;
  }

  init(TivioLogLevels logLevel) {
    if (_instance._logger == null) {
      print('Initializing tivio logger with level: $logLevel');
      _instance._logger = DartLogger.Logger(level: Logger.tivioLogLevelsToDartLoggerLevels(logLevel));
    }
  }

  info(dynamic message) {
    _getLogger()!.i(message);
  }

  debug(dynamic message) {
    _getLogger()!.d(message);
  }

  verbose(dynamic message) {
    _getLogger()!.v(message);
  }

  warning(dynamic message) {
    _getLogger()!.w(message);
  }

  error(dynamic message) {
    _getLogger()!.e(message);
  }

  DartLogger.Logger? _getLogger() {
    if (_logger == null) {
      throw Exception('Logger is not initialized.');
    }

    return _logger;
  }
}
